import React, { useEffect, useState } from 'react';
import request from 'umi-request';
import moment from 'moment';
import HistoryInfo from '../index';

const Demo = () => {
  const [data, setData] = useState([]);
  const [series, setSeries] = useState([]);
  const [columns, setColumns] = useState([
    {
      title: '采集时间',
      dataIndex: 'time',
      key: 'time',
    },
  ]);

  useEffect(() => {
    fetchData(initialParams);
  }, []);

  const fetchData = (params = {}) => {
    request(baseUrl + '/Publish/Monitor/Device/SensorsDataForStation', {
      method: 'post',
      data: params,
    }).then((res) => {
      let resData = response.data;
      let columnsData = resData.map((item, index) => {
        return {
          title: `${item.EquipmentName}-${item.sensorName}${
            item.unit ? '(' + item.unit + ')' : ''
          }`,
          dataIndex: `value${index + 1}`,
          key: `value${index + 1}`,
        };
      });
      let tableData = resData[0].dataModel.map((item, index) => ({ key: index, time: item.PT }));
      tableData.forEach((item, i) => {
        resData.forEach((child, index) => {
          child.dataModel.forEach((value, j) => {
            if (i === j) item[`value${index + 1}`] = value.PV;
          });
        });
      });
      setData(tableData);
      setColumns([...columns, ...columnsData]);
      handleSeries();
    });
  };

  const handleSeries = () => {
    let resData = response.data;
    let seriesData = [];
    resData.forEach((item) => {
      let data = [];
      let obj = {};
      obj.name = item.EquipmentName + item.sensorName;
      item.dataModel.forEach((child) => {
        data.push({
          x: moment(child.PT).valueOf(),
          y: child.PV,
        });
      });
      obj.data = data;
      seriesData.push(obj);
    });
    setSeries(seriesData);
  };

  const onChangeParams = (value = []) => {
    let params = initialParams;
    const { dateRange, ignoreOutliers, zoom, unit } = value;
    let requestArr = [];
    dateRange.forEach((item) => {
      let param = {
        ...params,
        stream: params.stream.map((child) => ({
          ...child,
          dateFrom: item.dateFrom,
          dateTo: item.dateTo,
        })),
        ignoreOutliers,
        zoom,
        unit,
      };
      requestArr.push(fetchData(param));
    });
    Promise.all(requestArr).then((values) => {
      console.log(values);
    });
  };

  return (
    <HistoryInfo
      title={'指标曲线'}
      columns={columns}
      dataSource={data}
      chartOptions={{ series }}
      tableProps={{ bordered: true }}
      onChange={onChangeParams}
    />
  );
};

export default Demo;

const baseUrl = 'http://192.168.10.150:8777';

const initialParams = {
  stream: [
    {
      stationCode: 'EGBF00000006',
      sensors: '出水瞬时流量,今日供水量,今日用电量',
      pointVersions: '二供泵房',
      dateFrom: '2021-03-15 16:01:21',
      dateTo: '2021-03-16 16:01:21',
    },
    {
      stationCode: 'EGJZ00007117',
      sensors: '进水压力,出水压力,泵1状态',
      pointVersions: '二供机组',
      dateFrom: '2021-03-15 16:01:21',
      dateTo: '2021-03-16 16:01:21',
    },
  ],
  ignoreOutliers: false, // 过滤异常值
  isVertical: false, // 是否展示竖表
  zoom: '', // 数据抽稀
  unit: '', // 数据抽稀 min h
};

const response = {
  code: 0,
  msg: 'Ok',
  data: [
    {
      stationCode: 'EGBF00000006',
      sensorName: '出水瞬时流量',
      dataModel: [
        {
          PV: 8.38,
          PT: '2021-03-15 16:03:49',
        },
        {
          PV: 8.67,
          PT: '2021-03-15 16:08:50',
        },
        {
          PV: 9.32,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 9.65,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 9.63,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 2,
      EquipmentName: '温州嵇师村低压区智慧集成泵房',
      unit: 'm³/h',
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
    {
      stationCode: 'EGBF00000006',
      sensorName: '今日供水量',
      dataModel: [
        {
          PV: 179,
          PT: '2021-03-15 16:03:49',
        },
        {
          PV: 179,
          PT: '2021-03-15 16:08:50',
        },
        {
          PV: 181,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 182,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 182,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 2,
      EquipmentName: '温州嵇师村低压区智慧集成泵房',
      unit: 'm³',
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
    {
      stationCode: 'EGBF00000006',
      sensorName: '今日用电量',
      dataModel: [
        {
          PV: 34,
          PT: '2021-03-15 16:03:49',
        },
        {
          PV: 34,
          PT: '2021-03-15 16:08:50',
        },
        {
          PV: 35,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 35,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 35,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 0,
      EquipmentName: '温州嵇师村低压区智慧集成泵房',
      unit: 'kWh',
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
    {
      stationCode: 'EGJZ00007117',
      sensorName: '进水压力',
      dataModel: [
        {
          PV: 0.08,
          PT: '2021-03-15 16:04:21',
        },
        {
          PV: 0.09,
          PT: '2021-03-15 16:09:22',
        },
        {
          PV: 0.09,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 0.08,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 0.08,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 2,
      EquipmentName: '温州嵇师村低压区智慧集成泵房-低区',
      unit: 'MPa',
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
    {
      stationCode: 'EGJZ00007117',
      sensorName: '出水压力',
      dataModel: [
        {
          PV: 0.33,
          PT: '2021-03-15 16:04:21',
        },
        {
          PV: 0.34,
          PT: '2021-03-15 16:09:22',
        },
        {
          PV: 0.33,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 0.32,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 0.32,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 2,
      EquipmentName: '温州嵇师村低压区智慧集成泵房-低区',
      unit: 'MPa',
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
    {
      stationCode: 'EGJZ00007117',
      sensorName: '泵1状态',
      dataModel: [
        {
          PV: 1,
          PT: '2021-03-15 16:04:21',
        },
        {
          PV: 1,
          PT: '2021-03-15 16:09:22',
        },
        {
          PV: 1,
          PT: '2021-03-15 16:18:21',
        },
        {
          PV: 1,
          PT: '2021-03-15 16:23:23',
        },
        {
          PV: 1,
          PT: '2021-03-15 16:28:24',
        },
      ],
      decimalPoint: 0,
      EquipmentName: '温州嵇师村低压区智慧集成泵房-低区',
      unit: null,
      normalData: [],
      dataModelAbnormal: [],
      alarmHisList: [],
      AreaCode: null,
      SensorType: null,
      Min_Data: null,
      Avg_Data: null,
      MinDatas: [],
      MaxDatas: [],
    },
  ],
};
